<?php

namespace Service;

use Util\InstanceProvider;
use Doctrine\ORM\EntityManager;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;

class ShellScriptCommands {

    /** @var EntityManager $entityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }


    public static function getLogInfo($msg)
    {
        return 'echo -e "\e[96m \n >>>>>>>>>>>>>> ' . $msg . ' <<<<<<<<<<<<< \e[39m "' . PHP_EOL;
    }

    public static function getLogSuccess($msg)
    {
        return 'echo -e "\e[92m >>>>>>>>>>>>>> ' . $msg . ' <<<<<<<<<<<<< \e[39m \n"' . PHP_EOL;
    }

    public static function getLogError($msg)
    {
        return 'echo -e "\e[91m >>>>>>>>>>>>>> ' . $msg . ' <<<<<<<<<<<<< \e[39m \n"' . PHP_EOL;
    }

    public static function getComment($comment)
    {
        return "# {$comment}" . PHP_EOL . PHP_EOL;
    }

    public static function tab()
    {
        return '    ';
    }

    /*******************************
     *** Directory\File Commands ***
     *******************************/

    public static function createPath($path)
    {
        return 'mkdir -p -m 775 ' . $path . self::orMsgErrorAndExit("Error ao tentar criar o diretório $path  :(") . PHP_EOL;
    }

    public static function copyFile($filePath, $destiny)
    {
        return "cp {$filePath}  {$destiny}/" . self::orMsgErrorAndExit("Error ao tentar copiar diretório :(") . PHP_EOL;
    }

    public static function cd($path)
    {
        return "cd {$path}" . self::orMsgErrorAndExit("Error ao tentar dar cd no diretório {$path} :(") . PHP_EOL;
    }

    public static function executeShellScript($fileName)
    {
        return "./{$fileName}" . self::orMsgErrorAndExit("Error ao tentar executar o script {$fileName} :(") . PHP_EOL;
    }

    public static function executeShellScriptNoTreatment($fileName)
    {
        return "./{$fileName}" . PHP_EOL;
    }

    /************************
     ***** Git Commands *****
     ************************/

    public static function gitClone($url, $directory)
    {
        return "git clone {$url} ./{$directory}/."  . self::orMsgErrorAndExit("Error ao tentar executar git clone no repositório {$url} :(") . PHP_EOL;
    }

    public static function gitFetchTags()
    {
        return "git fetch --tags"  . self::orMsgErrorAndExit("Error ao tentar executar git fetch --tafs :(") . PHP_EOL;
    }

    public static function gitFetch($flag = '')
    {
        return "git fetch {$flag}"  . self::orMsgErrorAndExit("Error ao tentar executar git fetch {$flag} :(") . PHP_EOL;
    }

    public static function gitCheckout($branch, $flag = '')
    {
        return "git checkout {$flag} {$branch}"  . self::orMsgErrorAndExit("Error ao tentar executar git checkout na branch {$branch} :(") . PHP_EOL;
    }

    public static function gitReset($flag = '')
    {
        return "git reset {$flag}"  . self::orMsgErrorAndExit("Error ao tentar executar git reset {$flag} :(") . PHP_EOL;
    }

    public static function gitPull($branch)
    {
        return "git pull origin {$branch}"  . self::orMsgErrorAndExit("Error ao tentar executar git pull na branch {$branch} :(") . PHP_EOL;
    }

    public static function gitBranch($branchName)
    {
        return "git branch {$branchName}"  . self::orMsgErrorAndExit("Error ao tentar executar git branch na branch {$branchName} :(") . PHP_EOL;
    }

    public static function orMsgErrorAndExit($msg)
    {
        $errorMsg = 'echo -e "\e[91m >>>>>>>>>>>>>> ' . $msg . ' <<<<<<<<<<<<< \e[39m";';
        return " || { " . $errorMsg . " exit 1; }";
    }



}